@@ -181,10 +181,10 @@ namespace lsp
                 : [bf] "+r" (bf), [bc] "+r" (bc), [count] "+r" (count)
                 : [kf] "r" (&kf)
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v20", "v21", "v22", "v23"
             );
         }
 
@@ -325,10 +325,10 @@ namespace lsp
                 : [bf] "+r" (bf), [bc] "+r" (bc), [count] "+r" (count)
                 : [kf] "r" (&kf)
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v20", "v21", "v22", "v23"
             );
         }
 
@@ -418,10 +418,10 @@ namespace lsp
                 : [bf] "+r" (bf), [bc] "+r" (bc), [count] "+r" (count)
                 : [kf] "r" (&kf)
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v20", "v21", "v22", "v23"
             );
         }
 
@@ -558,12 +558,12 @@ namespace lsp
                 : [bf] "+r" (bf), [bc] "+r" (bc), [count] "+r" (count)
                 : [kf] "r" (&kf)
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3",
-                  "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q20", "q21", "q22", "q23",
-                  "q24", "q25", "q26", "q27",
-                  "q28", "q29", "q30", "q31"
+                  "v0", "v1", "v2", "v3",
+                  "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v20", "v21", "v22", "v23",
+                  "v24", "v25", "v26", "v27",
+                  "v28", "v29", "v30", "v31"
             );
         }
     }
