@@ -128,8 +128,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -142,8 +142,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -156,8 +156,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -170,8 +170,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -283,9 +283,9 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19",
-                   "q24", "q25", "q26", "q27"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19",
+                   "v24", "v25", "v26", "v27"
              );
          }
 
@@ -298,9 +298,9 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19",
-                   "q24", "q25", "q26", "q27"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19",
+                   "v24", "v25", "v26", "v27"
              );
          }
 
@@ -404,8 +404,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -418,8 +418,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -432,8 +432,8 @@ namespace lsp
                    [count] "+r" (count)
                  :
                  : "cc", "memory",
-                   "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                   "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                   "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                   "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
              );
          }
 
@@ -549,9 +549,9 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19",
-                  "q24", "q25", "q26", "q27"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19",
+                  "v24", "v25", "v26", "v27"
             );
         }
 
@@ -686,8 +686,8 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
             );
         }
 
@@ -700,8 +700,8 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
             );
         }
 
@@ -714,8 +714,8 @@ namespace lsp
                   [count] "+r" (count)
                 :
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3" , "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
             );
         }
 
