@@ -34,7 +34,7 @@ namespace lsp
     #define OP_RSEL(a, b)      b
 
     #define OP_VV2_CORE(DST, SRC, OP, SEL) \
-        __ASM_EMIT("subs        %[count], $32") \
+        __ASM_EMIT("subs        %[count], #32") \
         __ASM_EMIT("blo         2f") \
         /* 32x blocks */ \
         __ASM_EMIT("1:") \
@@ -48,13 +48,13 @@ namespace lsp
         __ASM_EMIT(OP ".f32     q5, q5, q13") \
         __ASM_EMIT(OP ".f32     q6, q6, q14") \
         __ASM_EMIT(OP ".f32     q7, q7, q15") \
-        __ASM_EMIT("subs        %[count], $32") \
+        __ASM_EMIT("subs        %[count], #32") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0-q7}") \
-        __ASM_EMIT("add         %[" SRC "], $0x80") \
+        __ASM_EMIT("add         %[" SRC "], #0x80") \
         __ASM_EMIT("bhs         1b") \
         /* 16x block */ \
         __ASM_EMIT("2:") \
-        __ASM_EMIT("adds        %[count], $16") /* 32 - 16 */ \
+        __ASM_EMIT("adds        %[count], #16") /* 32 - 16 */ \
         __ASM_EMIT("blt         4f") \
         __ASM_EMIT("vldm        %[" SEL(DST, SRC) "], {q0-q3}") \
         __ASM_EMIT("vldm        %[" SEL(SRC, DST) "], {q8-q11}") \
@@ -62,41 +62,41 @@ namespace lsp
         __ASM_EMIT(OP ".f32     q1, q1, q9") \
         __ASM_EMIT(OP ".f32     q2, q2, q10") \
         __ASM_EMIT(OP ".f32     q3, q3, q11") \
-        __ASM_EMIT("sub         %[count], $16") \
+        __ASM_EMIT("sub         %[count], #16") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0-q3}") \
-        __ASM_EMIT("add         %[" SRC "], $0x40") \
+        __ASM_EMIT("add         %[" SRC "], #0x40") \
         /* 8x block */ \
         __ASM_EMIT("4:") \
-        __ASM_EMIT("adds        %[count], $8") /* 16 - 8 */ \
+        __ASM_EMIT("adds        %[count], #8") /* 16 - 8 */ \
         __ASM_EMIT("blt         6f") \
         __ASM_EMIT("vldm        %[" SEL(DST, SRC) "], {q0-q1}") \
         __ASM_EMIT("vldm        %[" SEL(SRC, DST) "], {q8-q9}") \
         __ASM_EMIT(OP ".f32     q0, q0, q8") \
         __ASM_EMIT(OP ".f32     q1, q1, q9") \
-        __ASM_EMIT("sub         %[count], $8") \
+        __ASM_EMIT("sub         %[count], #8") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0-q1}") \
-        __ASM_EMIT("add         %[" SRC "], $0x20") \
+        __ASM_EMIT("add         %[" SRC "], #0x20") \
         /* 4x block */ \
         __ASM_EMIT("6:") \
-        __ASM_EMIT("adds        %[count], $4") /* 8 - 4 */ \
+        __ASM_EMIT("adds        %[count], #4") /* 8 - 4 */ \
         __ASM_EMIT("blt         8f") \
         __ASM_EMIT("vldm        %[" SEL(DST, SRC) "], {q0}") \
         __ASM_EMIT("vldm        %[" SEL(SRC, DST) "], {q8}") \
         __ASM_EMIT(OP ".f32     q0, q0, q8") \
-        __ASM_EMIT("sub         %[count], $4") \
+        __ASM_EMIT("sub         %[count], #4") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0}") \
-        __ASM_EMIT("add         %[" SRC "], $0x10") \
+        __ASM_EMIT("add         %[" SRC "], #0x10") \
         /* 1x block */ \
         __ASM_EMIT("8:") \
-        __ASM_EMIT("adds        %[count], $3") /* 4 - 3 */ \
+        __ASM_EMIT("adds        %[count], #3") /* 4 - 3 */ \
         __ASM_EMIT("blt         10f") \
         __ASM_EMIT("9:") \
         __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[" SEL(DST, SRC) "]]") \
         __ASM_EMIT("vld1.32     {d16[], d17[]}, [%[" SEL(SRC, DST) "]]") \
         __ASM_EMIT(OP ".f32     q0, q0, q8") \
-        __ASM_EMIT("subs        %[count], $1") \
+        __ASM_EMIT("subs        %[count], #1") \
         __ASM_EMIT("vst1.32     {d0[0]}, [%[" DST "]]!") \
-        __ASM_EMIT("add         %[" SRC "], $0x04") \
+        __ASM_EMIT("add         %[" SRC "], #0x04") \
         __ASM_EMIT("bge         9b") \
         __ASM_EMIT("10:")
 
@@ -159,7 +159,7 @@ namespace lsp
     #undef OP_VV2_CORE
 
     #define OP_DIV2_CORE(DST, SRC, SEL)   \
-        __ASM_EMIT("subs            %[count], $16") \
+        __ASM_EMIT("subs            %[count], #16") \
         __ASM_EMIT("blo             2f") \
         /* 16x blocks */ \
         __ASM_EMIT("1:") \
@@ -190,12 +190,12 @@ namespace lsp
         __ASM_EMIT("vmul.f32        q2, q2, q6") \
         __ASM_EMIT("vmul.f32        q3, q3, q7") \
         __ASM_EMIT("vstm            %[" DST "]!, {q0-q3}") \
-        __ASM_EMIT("subs            %[count], $16") \
-        __ASM_EMIT("add             %[" SRC "], $0x40") \
+        __ASM_EMIT("subs            %[count], #16") \
+        __ASM_EMIT("add             %[" SRC "], #0x40") \
         __ASM_EMIT("bhs             1b") \
         /* 8x block */ \
         __ASM_EMIT("2:") \
-        __ASM_EMIT("adds            %[count], $8") \
+        __ASM_EMIT("adds            %[count], #8") \
         __ASM_EMIT("blt             4f") \
         __ASM_EMIT("vldm            %[" SEL(SRC, DST) "], {q0-q1}") \
         __ASM_EMIT("vldm            %[" SEL(DST, SRC) "], {q4-q5}") \
@@ -211,12 +211,12 @@ namespace lsp
         __ASM_EMIT("vmul.f32        q1, q13, q9") \
         __ASM_EMIT("vmul.f32        q0, q0, q4")                /* s1 / s2 */ \
         __ASM_EMIT("vmul.f32        q1, q1, q5") \
-        __ASM_EMIT("sub             %[count], $8") \
+        __ASM_EMIT("sub             %[count], #8") \
         __ASM_EMIT("vstm            %[" DST "]!, {q0-q1}") \
-        __ASM_EMIT("add             %[" SRC "], $0x20") \
+        __ASM_EMIT("add             %[" SRC "], #0x20") \
         /* 4x blocks */ \
         __ASM_EMIT("4:") \
-        __ASM_EMIT("adds            %[count], $4") \
+        __ASM_EMIT("adds            %[count], #4") \
         __ASM_EMIT("blt             6f") \
         __ASM_EMIT("vldm            %[" SEL(SRC, DST) "], {q0}") \
         __ASM_EMIT("vldm            %[" SEL(DST, SRC) "], {q4}") \
@@ -226,12 +226,12 @@ namespace lsp
         __ASM_EMIT("vrecps.f32      q12, q8, q0")               /* q12 = (2 - R*s2') */ \
         __ASM_EMIT("vmul.f32        q0, q12, q8")               /* q0 = s2" = s2' * (2 - R*s2) = 1/s2 */  \
         __ASM_EMIT("vmul.f32        q0, q0, q4")                /* s1 / s2 */ \
-        __ASM_EMIT("sub             %[count], $4") \
+        __ASM_EMIT("sub             %[count], #4") \
         __ASM_EMIT("vstm            %[" DST "]!, {q0}") \
-        __ASM_EMIT("add             %[" SRC "], $0x10") \
+        __ASM_EMIT("add             %[" SRC "], #0x10") \
         /* 1x blocks */ \
         __ASM_EMIT("6:") \
-        __ASM_EMIT("adds            %[count], $3") \
+        __ASM_EMIT("adds            %[count], #3") \
         __ASM_EMIT("blt             8f") \
         __ASM_EMIT("7:") \
         __ASM_EMIT("vld1.32         {d0[], d1[]}, [%[" SEL(SRC, DST) "]]") \
@@ -242,9 +242,9 @@ namespace lsp
         __ASM_EMIT("vrecps.f32      q12, q8, q0")               /* q12 = (2 - R*s2') */ \
         __ASM_EMIT("vmul.f32        q0, q12, q8")               /* q0 = s2" = s2' * (2 - R*s2) = 1/s2 */  \
         __ASM_EMIT("vmul.f32        q0, q0, q4")                /* s1 / s2 */ \
-        __ASM_EMIT("subs            %[count], $1") \
+        __ASM_EMIT("subs            %[count], #1") \
         __ASM_EMIT("vst1.32         {d0[0]}, [%[" DST "]]!") \
-        __ASM_EMIT("add             %[" SRC "], $0x04") \
+        __ASM_EMIT("add             %[" SRC "], #0x04") \
         __ASM_EMIT("bge             7b") \
         __ASM_EMIT("8:")
 
@@ -279,7 +279,7 @@ namespace lsp
     #undef OP_DIV2_CORE
 
     #define OP_VV3_CORE(DST, SRC1, SRC2, OP) \
-        __ASM_EMIT("subs        %[count], $32") \
+        __ASM_EMIT("subs        %[count], #32") \
         __ASM_EMIT("blo         2f") \
         /* 32x blocks */ \
         __ASM_EMIT("1:") \
@@ -293,12 +293,12 @@ namespace lsp
         __ASM_EMIT(OP ".f32     q5, q5, q13") \
         __ASM_EMIT(OP ".f32     q6, q6, q14") \
         __ASM_EMIT(OP ".f32     q7, q7, q15") \
-        __ASM_EMIT("subs        %[count], $32") \
+        __ASM_EMIT("subs        %[count], #32") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0-q7}") \
         __ASM_EMIT("bhs         1b") \
         /* 16x block */ \
         __ASM_EMIT("2:") \
-        __ASM_EMIT("adds        %[count], $16") /* 32 - 16 */ \
+        __ASM_EMIT("adds        %[count], #16") /* 32 - 16 */ \
         __ASM_EMIT("blt         4f") \
         __ASM_EMIT("vldm        %[" SRC1 "]!, {q0-q3}") \
         __ASM_EMIT("vldm        %[" SRC2 "]!, {q8-q11}") \
@@ -306,36 +306,36 @@ namespace lsp
         __ASM_EMIT(OP ".f32     q1, q1, q9") \
         __ASM_EMIT(OP ".f32     q2, q2, q10") \
         __ASM_EMIT(OP ".f32     q3, q3, q11") \
-        __ASM_EMIT("sub         %[count], $16") \
+        __ASM_EMIT("sub         %[count], #16") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0-q3}") \
         /* 8x block */ \
         __ASM_EMIT("4:") \
-        __ASM_EMIT("adds        %[count], $8") /* 16 - 8 */ \
+        __ASM_EMIT("adds        %[count], #8") /* 16 - 8 */ \
         __ASM_EMIT("blt         6f") \
         __ASM_EMIT("vldm        %[" SRC1 "]!, {q0-q1}") \
         __ASM_EMIT("vldm        %[" SRC2 "]!, {q8-q9}") \
         __ASM_EMIT(OP ".f32     q0, q0, q8") \
         __ASM_EMIT(OP ".f32     q1, q1, q9") \
-        __ASM_EMIT("sub         %[count], $8") \
+        __ASM_EMIT("sub         %[count], #8") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0-q1}") \
         /* 4x block */ \
         __ASM_EMIT("6:") \
-        __ASM_EMIT("adds        %[count], $4") /* 8 - 4 */ \
+        __ASM_EMIT("adds        %[count], #4") /* 8 - 4 */ \
         __ASM_EMIT("blt         8f") \
         __ASM_EMIT("vldm        %[" SRC1 "]!, {q0}") \
         __ASM_EMIT("vldm        %[" SRC2 "]!, {q8}") \
         __ASM_EMIT(OP ".f32     q0, q0, q8") \
-        __ASM_EMIT("sub         %[count], $4") \
+        __ASM_EMIT("sub         %[count], #4") \
         __ASM_EMIT("vstm        %[" DST "]!, {q0}") \
         /* 1x block */ \
         __ASM_EMIT("8:") \
-        __ASM_EMIT("adds        %[count], $3") /* 4 - 3 */ \
+        __ASM_EMIT("adds        %[count], #3") /* 4 - 3 */ \
         __ASM_EMIT("blt         10f") \
         __ASM_EMIT("9:") \
         __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[" SRC1 "]]!") \
         __ASM_EMIT("vld1.32     {d16[], d17[]}, [%[" SRC2 "]]!") \
         __ASM_EMIT(OP ".f32     q0, q0, q8") \
-        __ASM_EMIT("subs        %[count], $1") \
+        __ASM_EMIT("subs        %[count], #1") \
         __ASM_EMIT("vst1.32     {d0[0]}, [%[" DST "]]!") \
         __ASM_EMIT("bge         9b") \
         __ASM_EMIT("10:")
@@ -384,7 +384,7 @@ namespace lsp
     #undef OP_VV3_CORE
 
     #define OP_DIV3_CORE(DST, SRC1, SRC2)   \
-        __ASM_EMIT("subs            %[count], $16") \
+        __ASM_EMIT("subs            %[count], #16") \
         __ASM_EMIT("blo             2f") \
         /* 16x blocks */ \
         __ASM_EMIT("1:") \
@@ -415,11 +415,11 @@ namespace lsp
         __ASM_EMIT("vmul.f32        q2, q2, q6") \
         __ASM_EMIT("vmul.f32        q3, q3, q7") \
         __ASM_EMIT("vstm            %[" DST "]!, {q0-q3}") \
-        __ASM_EMIT("subs            %[count], $16") \
+        __ASM_EMIT("subs            %[count], #16") \
         __ASM_EMIT("bhs             1b") \
         /* 8x block */ \
         __ASM_EMIT("2:") \
-        __ASM_EMIT("adds            %[count], $8") \
+        __ASM_EMIT("adds            %[count], #8") \
         __ASM_EMIT("blt             4f") \
         __ASM_EMIT("vldm            %[" SRC2 "]!, {q0-q1}") \
         __ASM_EMIT("vldm            %[" SRC1 "]!, {q4-q5}") \
@@ -435,11 +435,11 @@ namespace lsp
         __ASM_EMIT("vmul.f32        q1, q13, q9") \
         __ASM_EMIT("vmul.f32        q0, q0, q4")                /* s1 / s2 */ \
         __ASM_EMIT("vmul.f32        q1, q1, q5") \
-        __ASM_EMIT("sub             %[count], $8") \
+        __ASM_EMIT("sub             %[count], #8") \
         __ASM_EMIT("vstm            %[" DST "]!, {q0-q1}") \
         /* 4x blocks */ \
         __ASM_EMIT("4:") \
-        __ASM_EMIT("adds            %[count], $4") \
+        __ASM_EMIT("adds            %[count], #4") \
         __ASM_EMIT("blt             6f") \
         __ASM_EMIT("vldm            %[" SRC2 "]!, {q0}") \
         __ASM_EMIT("vldm            %[" SRC1 "]!, {q4}") \
@@ -449,11 +449,11 @@ namespace lsp
         __ASM_EMIT("vrecps.f32      q12, q8, q0")               /* q12 = (2 - R*s2') */ \
         __ASM_EMIT("vmul.f32        q0, q12, q8")               /* q0 = s2" = s2' * (2 - R*s2) = 1/s2 */  \
         __ASM_EMIT("vmul.f32        q0, q0, q4")                /* s1 / s2 */ \
-        __ASM_EMIT("sub             %[count], $4") \
+        __ASM_EMIT("sub             %[count], #4") \
         __ASM_EMIT("vstm            %[" DST "]!, {q0}") \
         /* 1x blocks */ \
         __ASM_EMIT("6:") \
-        __ASM_EMIT("adds            %[count], $3") \
+        __ASM_EMIT("adds            %[count], #3") \
         __ASM_EMIT("blt             8f") \
         __ASM_EMIT("7:") \
         __ASM_EMIT("vld1.32         {d0[], d1[]}, [%[" SRC2 "]]!") \
@@ -464,7 +464,7 @@ namespace lsp
         __ASM_EMIT("vrecps.f32      q12, q8, q0")               /* q12 = (2 - R*s2') */ \
         __ASM_EMIT("vmul.f32        q0, q12, q8")               /* q0 = s2" = s2' * (2 - R*s2) = 1/s2 */  \
         __ASM_EMIT("vmul.f32        q0, q0, q4")                /* s1 / s2 */ \
-        __ASM_EMIT("subs            %[count], $1") \
+        __ASM_EMIT("subs            %[count], #1") \
         __ASM_EMIT("vst1.32         {d0[0]}, [%[" DST "]]!") \
         __ASM_EMIT("bge             7b") \
         __ASM_EMIT("8:")
@@ -486,7 +486,7 @@ namespace lsp
     #undef OP_DIV3_CORE
 
     #define FMOD_VV_CORE(DST, SRC1, INC1, SRC2, INC2, SEL)   \
-        __ASM_EMIT("subs            %[count], $16") \
+        __ASM_EMIT("subs            %[count], #16") \
         __ASM_EMIT("blo             2f") \
         /* 16x blocks */ \
         __ASM_EMIT("1:") \
@@ -529,11 +529,11 @@ namespace lsp
         __ASM_EMIT("vmls.f32        " SEL("q2", "q6") ", q10, " SEL("q6", "q2")) \
         __ASM_EMIT("vmls.f32        " SEL("q3", "q7") ", q11, " SEL("q7", "q3")) \
         __ASM_EMIT("vstm            %[" DST "]!, " SEL("{q0-q3}", "{q4-q7}")) \
-        __ASM_EMIT("subs            %[count], $16") \
+        __ASM_EMIT("subs            %[count], #16") \
         __ASM_EMIT("bhs             1b") \
         /* 8x block */ \
         __ASM_EMIT("2:") \
-        __ASM_EMIT("adds            %[count], $8") \
+        __ASM_EMIT("adds            %[count], #8") \
         __ASM_EMIT("blt             4f") \
         __ASM_EMIT("vldm            %[" SRC1 "]" INC1 ", {q0-q1}") \
         __ASM_EMIT("vldm            %[" SRC2 "]" INC2 ", {q4-q5}") \
@@ -556,10 +556,10 @@ namespace lsp
         __ASM_EMIT("vmls.f32        " SEL("q0", "q4") ", q8, " SEL("q4", "q0")) \
         __ASM_EMIT("vmls.f32        " SEL("q1", "q5") ", q9, " SEL("q5", "q1")) \
         __ASM_EMIT("vstm            %[" DST "]!, " SEL("{q0-q1}", "{q4-q5}")) \
-        __ASM_EMIT("sub             %[count], $8") \
+        __ASM_EMIT("sub             %[count], #8") \
         /* 4x blocks */ \
         __ASM_EMIT("4:") \
-        __ASM_EMIT("adds            %[count], $4") \
+        __ASM_EMIT("adds            %[count], #4") \
         __ASM_EMIT("blt             6f") \
         __ASM_EMIT("vldm            %[" SRC1 "]" INC1 ", {q0}") \
         __ASM_EMIT("vldm            %[" SRC2 "]" INC2 ", {q4}") \
@@ -573,10 +573,10 @@ namespace lsp
         __ASM_EMIT("vcvt.f32.s32    q8, q8") \
         __ASM_EMIT("vmls.f32        " SEL("q0", "q4") ", q8, " SEL("q4", "q0")) \
         __ASM_EMIT("vstm            %[" DST "]!, " SEL("{q0}", "{q4}")) \
-        __ASM_EMIT("sub             %[count], $4") \
+        __ASM_EMIT("sub             %[count], #4") \
         /* 1x blocks */ \
         __ASM_EMIT("6:") \
-        __ASM_EMIT("adds            %[count], $3") \
+        __ASM_EMIT("adds            %[count], #3") \
         __ASM_EMIT("blt             8f") \
         __ASM_EMIT("7:") \
         __ASM_EMIT("vld1.32         {d0[], d1[]}, [%[" SRC1 "]]" INC1) \
@@ -591,7 +591,7 @@ namespace lsp
         __ASM_EMIT("vcvt.f32.s32    q8, q8") \
         __ASM_EMIT("vmls.f32        " SEL("q0", "q4") ", q8, " SEL("q4", "q0")) \
         __ASM_EMIT("vst1.32         " SEL("{d0[0]}", "{d8[0]}") ", [%[" DST "]]!") \
-        __ASM_EMIT("subs            %[count], $1") \
+        __ASM_EMIT("subs            %[count], #1") \
         __ASM_EMIT("bge             7b") \
         __ASM_EMIT("8:")
 
