@@ -36,14 +36,12 @@ namespace lsp
                 LSP_DSP_VEC16(0x007fffff), // frac
                 LSP_DSP_VEC16(0x0000007f), // 127
                 LSP_DSP_VEC16(0x3f800000), // 1.0f
-                LSP_DSP_VEC16(0x3d888889), // C0 = 1/15 = 0.0666666701436043
-                LSP_DSP_VEC16(0x3d9d89d9), // C1 = 1/13 = 0.0769230797886848
-                LSP_DSP_VEC16(0x3dba2e8c), // C2 = 1/11 = 0.0909090936183929
-                LSP_DSP_VEC16(0x3de38e39), // C3 = 1/9 = 0.1111111119389534
-                LSP_DSP_VEC16(0x3e124925), // C4 = 1/7 = 0.1428571492433548
-                LSP_DSP_VEC16(0x3e4ccccd), // C5 = 1/5 = 0.2000000029802322
-                LSP_DSP_VEC16(0x3eaaaaab), // C6 = 1/3 = 0.3333333432674408
-                LSP_DSP_VEC16(0x3f800000)  // C7 = 1/1 = 1.0000000000000000
+                LSP_DSP_VEC16(0x3dba2e8c), // C0 = 1/11 = 0.0909090936183929
+                LSP_DSP_VEC16(0x3de38e39), // C1 = 1/9 = 0.1111111119389534
+                LSP_DSP_VEC16(0x3e124925), // C2 = 1/7 = 0.1428571492433548
+                LSP_DSP_VEC16(0x3e4ccccd), // C3 = 1/5 = 0.2000000029802322
+                LSP_DSP_VEC16(0x3eaaaaab), // C4 = 1/3 = 0.3333333432674408
+                LSP_DSP_VEC16(0x3f800000)  // C5 = 1/1 = 1.0000000000000000
             };
 
             static const float LOGB_C[] __lsp_aligned64 =
@@ -126,15 +124,7 @@ namespace lsp
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%zmm6, %%zmm7")    \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%zmm10, %%zmm11")  \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%zmm14, %%zmm15")  \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm6, %%zmm7")    \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm10, %%zmm11")  \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm14, %%zmm15")  \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm6, %%zmm7")    \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm10, %%zmm11")  \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm14, %%zmm15")  \
-            __ASM_EMIT("vmulps          %%zmm0, %%zmm3, %%zmm0")            /* zmm0 = y*(C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))))) */ \
+            __ASM_EMIT("vmulps          %%zmm0, %%zmm3, %%zmm0")            /* zmm0 = y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
             __ASM_EMIT("vmulps          %%zmm4, %%zmm7, %%zmm4")            \
             __ASM_EMIT("vmulps          %%zmm8, %%zmm11, %%zmm8")           \
             __ASM_EMIT("vmulps          %%zmm12, %%zmm15, %%zmm12")         \
@@ -171,11 +161,7 @@ namespace lsp
             __ASM_EMIT("vfmadd213ps     0x1c0 + %[L2C], %%zmm6, %%zmm7")    \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))) */ \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%zmm6, %%zmm7")    \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm6, %%zmm7")    \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm6, %%zmm7")    \
-            __ASM_EMIT("vmulps          %%zmm0, %%zmm3, %%zmm0")            /* zmm0 = y*(C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))))) */ \
+            __ASM_EMIT("vmulps          %%zmm0, %%zmm3, %%zmm0")            /* zmm0 = y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
             __ASM_EMIT("vmulps          %%zmm4, %%zmm7, %%zmm4")
 
         #define LOGN_CORE_X16 \
@@ -195,9 +181,7 @@ namespace lsp
             __ASM_EMIT("vfmadd213ps     0x180 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C3+Y*(C2+Y*(C1+C0*Y)) */ \
             __ASM_EMIT("vfmadd213ps     0x1c0 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))) */ \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))) */ \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%zmm2, %%zmm3")    /* zmm3 = C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))))) */ \
-            __ASM_EMIT("vmulps          %%zmm0, %%zmm3, %%zmm0")            /* zmm0 = y*(C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))))) */ \
+            __ASM_EMIT("vmulps          %%zmm0, %%zmm3, %%zmm0")            /* zmm0 = y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
 
         #define LOGN_CORE_X8 \
             __ASM_EMIT("vpsrld          $23, %%ymm0, %%ymm1")               /* ymm1 = ilog2(x) + 127 */ \
@@ -216,9 +200,7 @@ namespace lsp
             __ASM_EMIT("vfmadd213ps     0x180 + %[L2C], %%ymm2, %%ymm3")    /* ymm3 = C3+Y*(C2+Y*(C1+C0*Y)) */ \
             __ASM_EMIT("vfmadd213ps     0x1c0 + %[L2C], %%ymm2, %%ymm3")    /* ymm3 = C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))) */ \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%ymm2, %%ymm3")    /* ymm3 = C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))) */ \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%ymm2, %%ymm3")    /* ymm3 = C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%ymm2, %%ymm3")    /* ymm3 = C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))))) */ \
-            __ASM_EMIT("vmulps          %%ymm0, %%ymm3, %%ymm0")            /* ymm0 = y*(C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))))) */ \
+            __ASM_EMIT("vmulps          %%ymm0, %%ymm3, %%ymm0")            /* ymm0 = y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
 
         #define LOGN_CORE_X4 \
             __ASM_EMIT("vpsrld          $23, %%xmm0, %%xmm1")               /* xmm1 = ilog2(x) + 127 */ \
@@ -237,9 +219,7 @@ namespace lsp
             __ASM_EMIT("vfmadd213ps     0x180 + %[L2C], %%xmm2, %%xmm3")    /* xmm3 = C3+Y*(C2+Y*(C1+C0*Y)) */ \
             __ASM_EMIT("vfmadd213ps     0x1c0 + %[L2C], %%xmm2, %%xmm3")    /* xmm3 = C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))) */ \
             __ASM_EMIT("vfmadd213ps     0x200 + %[L2C], %%xmm2, %%xmm3")    /* xmm3 = C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))) */ \
-            __ASM_EMIT("vfmadd213ps     0x240 + %[L2C], %%xmm2, %%xmm3")    /* xmm3 = C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
-            __ASM_EMIT("vfmadd213ps     0x280 + %[L2C], %%xmm2, %%xmm3")    /* xmm3 = C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y)))))) */ \
-            __ASM_EMIT("vmulps          %%xmm0, %%xmm3, %%xmm0")            /* xmm0 = y*(C7+Y*(C6+Y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))))) */ \
+            __ASM_EMIT("vmulps          %%xmm0, %%xmm3, %%xmm0")            /* xmm0 = y*(C5+Y*(C4+Y*(C3+Y*(C2+Y*(C1+C0*Y))))) */ \
 
 
         #define LOGB_CORE_X64 \
