@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 31 мар. 2020 г.
@@ -303,6 +303,34 @@ namespace lsp
             );
         }
 
+        void abs_max2(float *dst, const float *src, size_t count)
+        {
+            IF_ARCH_X86(size_t off);
+            ARCH_X86_ASM
+            (
+                ABS_OP2_CORE("max", "dst", "dst", "src", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r" (dst), [src] "r" (src),
+                  [X_SIGN] "m" (abs_vv_const)
+                : "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7"
+            );
+        }
+
+        void abs_min2(float *dst, const float *src, size_t count)
+        {
+            IF_ARCH_X86(size_t off);
+            ARCH_X86_ASM
+            (
+                ABS_OP2_CORE("min", "dst", "dst", "src", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r" (dst), [src] "r" (src),
+                  [X_SIGN] "m" (abs_vv_const)
+                : "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7"
+            );
+        }
+
         void abs_add3(float *dst, const float *src1, const float *src2, size_t count)
         {
             IF_ARCH_X86(size_t off);
@@ -387,11 +415,39 @@ namespace lsp
             );
         }
 
+        void abs_max3(float *dst, const float *src1, const float *src2, size_t count)
+        {
+            IF_ARCH_X86(size_t off);
+            ARCH_X86_ASM
+            (
+                ABS_OP2_CORE("max", "dst", "src1", "src2", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r" (dst), [src1] "r" (src1), [src2] "r" (src2),
+                  [X_SIGN] "m" (abs_vv_const)
+                : "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7"
+            );
+        }
+
+        void abs_min3(float *dst, const float *src1, const float *src2, size_t count)
+        {
+            IF_ARCH_X86(size_t off);
+            ARCH_X86_ASM
+            (
+                ABS_OP2_CORE("min", "dst", "src1", "src2", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r" (dst), [src1] "r" (src1), [src2] "r" (src2),
+                  [X_SIGN] "m" (abs_vv_const)
+                : "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7"
+            );
+        }
+
     #undef ABS_OP2_CORE
 
     #undef OP_DSEL
     #undef OP_RSEL
-    }
-}
+    } /* namespace sse */
+} /* namespace lsp */
 
 #endif /* PRIVATE_DSP_ARCH_X86_SSE_PMATH_ABS_VV_H_ */
