@@ -89,7 +89,7 @@ PTEST_BEGIN("dsp.dynamics", compressor_x2_gain, 5, 1000)
             return;
 
         char buf[80];
-        sprintf(buf, "%s x %d", label, int(count));
+        snprintf(buf, sizeof(buf), "%s x %d", label, int(count));
         printf("Testing %s points...\n", buf);
 
         PTEST_LOOP(buf,
