@@ -45,6 +45,12 @@ namespace lsp
             void limit_saturate1(float *dst, size_t count);
             void limit_saturate2(float *dst, const float *src, size_t count);
         }
+
+        namespace avx512
+        {
+            void limit_saturate1(float *dst, size_t count);
+            void limit_saturate2(float *dst, const float *src, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -192,6 +198,9 @@ UTEST_BEGIN("dsp.float", limit_saturate)
         IF_ARCH_X86(CALL(avx2::limit_saturate1, 32));
         IF_ARCH_X86(CALL(avx2::limit_saturate2, 32));
 
+        IF_ARCH_X86(CALL(avx512::limit_saturate1, 64));
+        IF_ARCH_X86(CALL(avx512::limit_saturate2, 64));
+
         IF_ARCH_ARM(CALL(neon_d32::limit_saturate1, 16));
         IF_ARCH_ARM(CALL(neon_d32::limit_saturate2, 16));
 
